<?php
/**
 *	{$view_path}
 *
 *	@author		{$author}
 *	@package	{$project_id}
 *	@version	$Id: skel.view.php,v 1.6 2006/03/07 16:23:18 fujimoto Exp $
 */

/**
 *	{$forward_name}ӥ塼μ
 *
 *	@author		{$author}
 *	@access		public
 *	@package	{$project_id}
 */
class {$view_class} extends Ethna_ViewClass
{
	/**
	 *	
	 *
	 *	@access	public
	 */
	function preforward()
	{
	}
}
?>
